"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var typescript_1 = tslib_1.__importDefault(require("typescript"));
var path_1 = require("path");
var libraryName = 'ant-design-svelte';
var printer = typescript_1.default.createPrinter();
function getImportedStructs(node) {
    var structs = new Set();
    node.forEachChild(function (importChild) {
        if (typescript_1.default.isImportClause(importChild) &&
            importChild.namedBindings &&
            typescript_1.default.isNamedImports(importChild.namedBindings)) {
            importChild.namedBindings.forEachChild(function (namedBinding) {
                var importSpecifier = namedBinding;
                structs.add({ importName: importSpecifier.name.text });
            });
        }
    });
    return structs;
}
function createDistAst(struct, options) {
    var astNodes = [];
    var libraryDirectory = options.libraryDirectory, style = options.style;
    var importPath = path_1.join(libraryName, libraryDirectory, struct.importName.toLowerCase());
    var scriptNode = typescript_1.default.createImportDeclaration(undefined, undefined, typescript_1.default.createImportClause(typescript_1.default.createIdentifier(struct.importName), undefined), typescript_1.default.createLiteral(importPath));
    astNodes.push(scriptNode);
    if (style) {
        var stylePath = style === 'css'
            ? importPath + "/style/index.css"
            : importPath + "/style/index";
        var styleNode = typescript_1.default.createImportDeclaration(undefined, undefined, undefined, typescript_1.default.createLiteral(stylePath));
        astNodes.push(styleNode);
    }
    return astNodes;
}
function createTransformer(options) {
    var transformer = function (context) {
        var visitor = function (node) {
            if (typescript_1.default.isSourceFile(node)) {
                return typescript_1.default.visitEachChild(node, visitor, context);
            }
            if (!typescript_1.default.isImportDeclaration(node)) {
                return node;
            }
            var importedLibName = node.moduleSpecifier.text;
            if (libraryName !== importedLibName) {
                return node;
            }
            var structs = getImportedStructs(node);
            if (structs.size === 0) {
                return node;
            }
            return Array.from(structs).reduce(function (acc, struct) {
                var nodes = createDistAst(struct, options);
                return acc.concat(nodes);
            }, []);
        };
        return function (node) { return typescript_1.default.visitNode(node, visitor); };
    };
    return transformer;
}
var svelteImport = function (options) { return function (input) {
    var result = typescript_1.default.transform(typescript_1.default.createSourceFile(input.filename, input.content, typescript_1.default.ScriptTarget.ES2016, true), [createTransformer(options)]);
    var transformedSourceFile = result.transformed[0];
    var resultCode = printer.printFile(transformedSourceFile);
    return {
        code: resultCode,
    };
}; };
// svelteImport({
//   libraryDirectory: 'components',
//   style: true,
// })({
//   content: `import { Button } from 'ant-design-svelte'`,
//   filename: 'sss',
// });
// yarn ts-node -T scripts/helpers/svelte-import.ts
module.exports = svelteImport;
